/**************************************************************************************************|
|* Copyright 2021 Hycon Technology, Corp.                                                         *|
|* http://www.hycontek.com/                                                                       *|
|* Description:                                                                                   *|
|*                                                                                                *|
|**************************************************************************************************/

/**************************************************************************************************|
|*  Includes                                                                                      *|
|**************************************************************************************************/
#include <hy17m26sfr.h>
#include <I2C.h>
#include <GPIO.h>
/**************************************************************************************************|
|*  Static Function                                                                               *|
|**************************************************************************************************/

/**************************************************************************************************|
|*  Generic Peripheral Library                                                                    *|
|**************************************************************************************************/

/*----------------------------------------------------------------------------------------------------------------------------------------------------|
|  Function: I2C0_Open                                                                      			     				   											|
|                                                                                                 																					|
|  Parameters:                                                                                                                                                         		     |	
|         dbr         - [in]	0~0xff			data baud rate = I2C_CLK / [4*(dbr+1)]																	 |
|  Returns:                                                                               		                                                                                  |
|         None               		                   		                   		                   		                   		                   		                       |
|                                                                                       		                   		                   		                                        
|  Description:                                                                                																					 
|         This function is used to open I2C               														   
|-------------------------------------------------------------------------------------------------------------------------------------------------------*/
void I2C0_Open( unsigned char dbr)	   // data baud rate = I2C_CLK / [4*(dbr+1)]
{
	I2C0Enable();
	I2C0_GCRstEnable();
	I2C0_SCLCLKSet(dbr);
	I2C0_SendData(0xff); 
	I2CIE_Enable();			//I2C INT Enable
	I2CERIE_Enable();	//I2C ERROR INT Enable
}

/*----------------------------------------------------------------------------------------------------------------------------------------------------|
|  Function: I2C0_TimeOutEnable                                                                      			     				   							|
|                                                                                                 																			     		|
|  Parameters:                                                                                                                                                         	       |	
|         cks         - [in]	DI2C_CPUCKDIV1 / DI2C_CPUCKDIV2 / DI2C_CPUCKDIV4 / DI2C_CPUCKDIV8		     	 |
|         							DI2C_CPUCKDIV16 / DI2C_CPUCKDIV32 / DI2C_CPUCKDIV64 / DI2C_CPUCKDIV128	   |
|         cyc         - [in]     I2CTLT_CLKPS1 / I2CTLT_CLKPS2 / I2CTLT_CLKPS3 / I2CTLT_CLKPS4							 |
|                                   I2CTLT_CLKPS5 / I2CTLT_CLKPS6 / I2CTLT_CLKPS7 / I2CTLT_CLKPS8							 |
|                                   I2CTLT_CLKPS9 / I2CTLT_CLKPS10 / I2CTLT_CLKPS11 / I2CTLT_CLKPS12					 |
|                                   I2CTLT_CLKPS13 / I2CTLT_CLKPS14 / I2CTLT_CLKPS15 / I2CTLT_CLKPS16					 |
|                                                                                                                                                                                       |
|  Returns:                                                                               		                                                                                  |
|         None               		                   		                   		                   		                   		                   		                       |
|                                                                                       		                   		                   		                                        
|  Description:                                                                                																					 
|         This function is used to open Time-out                         														   
|-------------------------------------------------------------------------------------------------------------------------------------------------------*/
void I2C0_TimeOutOpen(unsigned char cks,	// Time-out Clock Pre-scale
					                   unsigned char cyc)		// Time-out Limit
{
	I2C0_TimeOutEnable();
	I2C0_TimeOutCLKSel(cks);
	I2C0_TimeOutCYCSel(cyc);
}


/*----------------------------------------------------------------------------------------------------------------------------------------------------|
|  Function: I2C_Ctrl                                                                      			     				   							|
|                                                                                                 																			     		|
|  Parameters:                                                                                                                                                         	       |	
|         S         - [in]	0 , 1	    	// Start   command                                                                                                            |
|         P         - [in]   0 , 1	   		// Stop     command                                                                                           |
|         I           - [in]   0 , 1	     // Interrupt    command                                                                                            |
|         A         - [in]   0 , 1	       // Acknowledge   command                                                                                        |
|                                                                                                                                                                                       |
|  Returns:                                                                               		                                                                                  |
|         None               		                   		                   		                   		                   		                   		                       |
|                                                                                       		                   		                   		                                        
|  Description:                                                                                																					 
|         This function is used to Ctrl SPIA                         														   
|-------------------------------------------------------------------------------------------------------------------------------------------------------*/
void I2C0_Ctrl( unsigned char S,		// Start
                       unsigned char P,		// Stop
                       unsigned char I,		// Interrupt
                       unsigned char A) 	// Acknowledge
{
 A|=(S<<3);
 A|=(P<<2);
 A|=(I<<1);
 I2C0_SPIA(A);
}
/*----------------------------------------------------------------------------------------------------------------------------------------------------|
|  Function: I2C_SlaveSet                                                                   			     				   							|
|                                                                                                 																			     		|
|  Parameters:                                                                                                                                                         	       |	
|         sid         - [in]	 0x00~0xff																																			|
|  Returns:                                                                               		                                                                                  |
|         None               		                   		                   		                   		                   		                   		                       |
|                                                                                       		                   		                   		                                        
|  Description:                                                                                																					 
|         This function is used to set slave mode                         														   
|-------------------------------------------------------------------------------------------------------------------------------------------------------*/
void I2C0_SlaveSet(unsigned char sid)
{
	I2C0_GCRstDisable();
	I2C0_SlaveModeEnable();
	I2C0_SlaveAddSet(sid);
	I2C0_SendData(0xff);
}

/*----------------------------------------------------------------------------------------------------------------------------------------------------|
|  Function: I2C2_Open                                                                      			     				   											|
|                                                                                                 																					|
|  Parameters:                                                                                                                                                         		     |	
|         dbr         - [in]	0~0xff			data baud rate = I2C_CLK / [4*(dbr+1)]																	 |
|  Returns:                                                                               		                                                                                  |
|         None               		                   		                   		                   		                   		                   		                       |
|                                                                                       		                   		                   		                                        
|  Description:                                                                                																					 
|         This function is used to open I2C               														   
|-------------------------------------------------------------------------------------------------------------------------------------------------------*/
void I2C2_Open( unsigned char dbr)	   // data baud rate = I2C_CLK / [4*(dbr+1)]
{
	I2C2Enable();
	I2C2_GCRstEnable();
	I2C2_SCLCLKSet(dbr);
	I2C2_SendData(0xff);
	I2C2IE_Enable();			//I2C INT Enable
	I2CER2IE_Enable();	//I2C ERROR INT Enable
}

/*----------------------------------------------------------------------------------------------------------------------------------------------------|
|  Function: I2C2_TimeOutEnable                                                                      			     				   							|
|                                                                                                 																			     		|
|  Parameters:                                                                                                                                                         	       |	
|         cks         - [in]	DI2C_CPUCKDIV1 / DI2C_CPUCKDIV2 / DI2C_CPUCKDIV4 / DI2C_CPUCKDIV8		     	 |
|         							DI2C_CPUCKDIV16 / DI2C_CPUCKDIV32 / DI2C_CPUCKDIV64 / DI2C_CPUCKDIV128	   |
|         cyc         - [in]     I2CTLT_CLKPS1 / I2CTLT_CLKPS2 / I2CTLT_CLKPS3 / I2CTLT_CLKPS4							 |
|                                   I2CTLT_CLKPS5 / I2CTLT_CLKPS6 / I2CTLT_CLKPS7 / I2CTLT_CLKPS8							 |
|                                   I2CTLT_CLKPS9 / I2CTLT_CLKPS10 / I2CTLT_CLKPS11 / I2CTLT_CLKPS12					 |
|                                   I2CTLT_CLKPS13 / I2CTLT_CLKPS14 / I2CTLT_CLKPS15 / I2CTLT_CLKPS16					 |
|                                                                                                                                                                                       |
|  Returns:                                                                               		                                                                                  |
|         None               		                   		                   		                   		                   		                   		                       |
|                                                                                       		                   		                   		                                        
|  Description:                                                                                																					 
|         This function is used to open Time-out                         														   
|-------------------------------------------------------------------------------------------------------------------------------------------------------*/
void I2C2_TimeOutOpen(unsigned char cks,	// Time-out Clock Pre-scale
		              unsigned char cyc)		// Time-out Limit
{
	I2C2_TimeOutEnable();
	I2C2_TimeOutCLKSel(cks);
	I2C2_TimeOutCYCSel(cyc);
}


/*----------------------------------------------------------------------------------------------------------------------------------------------------|
|  Function: I2C2_Ctrl                                                                      			     				   							|
|                                                                                                 																			     		|
|  Parameters:                                                                                                                                                         	       |	
|         S         - [in]	0 , 1	    	// Start   command                                                                                                            |
|         P         - [in]   0 , 1	   		// Stop     command                                                                                           |
|         I           - [in]   0 , 1	     // Interrupt    command                                                                                            |
|         A         - [in]   0 , 1	       // Acknowledge   command                                                                                        |
|                                                                                                                                                                                       |
|  Returns:                                                                               		                                                                                  |
|         None               		                   		                   		                   		                   		                   		                       |
|                                                                                       		                   		                   		                                        
|  Description:                                                                                																					 
|         This function is used to Ctrl SPIA                         														   
|-------------------------------------------------------------------------------------------------------------------------------------------------------*/
void I2C2_Ctrl( unsigned char S,		// Start
                       unsigned char P,		// Stop
                       unsigned char I,		// Interrupt
                       unsigned char A) 	// Acknowledge
{
 A|=(S<<3);
 A|=(P<<2);
 A|=(I<<1);
 I2C2_SPIA(A);
}
/*----------------------------------------------------------------------------------------------------------------------------------------------------|
|  Function: I2C_SlaveSet                                                                   			     				   							|
|                                                                                                 																			     		|
|  Parameters:                                                                                                                                                         	       |	
|         sid         - [in]	 0x00~0xff																																			|
|  Returns:                                                                               		                                                                                  |
|         None               		                   		                   		                   		                   		                   		                       |
|                                                                                       		                   		                   		                                        
|  Description:                                                                                																					 
|         This function is used to set slave mode                         														   
|-------------------------------------------------------------------------------------------------------------------------------------------------------*/
void I2C2_SlaveSet(unsigned char sid)
{
	I2C2_GCRstDisable();
	I2C2_SlaveModeEnable();
	I2C2_SlaveAddSet(sid);
	I2C2_SendData(0xff);
}

