/**************************************************************************************************|
|* Copyright 2021 Hycon Technology, Corp.                                                         *|
|* http://www.hycontek.com/                                                                       *|
|* Description:                                                                                   *|
|* - Generic Peripheral Library: A general and functional Interface for the specific Peripheral   *|
|* - Low Level Peripheral Access: Register-Bits Level access Macro, user must take care           *|
|*   of calling procedure and hardware constraints                                                *|
|* - Support Target: HY17M Series                                                                 *|
|**************************************************************************************************/

/**************************************************************************************************|
|*                               Peripheral Register Bits field                                   *|
|**************************************************************************************************/
#include <ADC.h>


// PWRCN //
#define ENBGR                      7
#define ENBGR_MSK                 (1 << ENBGR)
#define ENBGR_ENABLE              (1 << ENBGR)
#define ENBGR_DISABLE             (0 << ENBGR)

#define LDOC                       4
#define LDOC_MSK                  (7 << LDOC)
#define LDOC_5V0                  (7 << LDOC)
#define LDOC_4V5                  (6 << LDOC)
#define LDOC_4V0                  (5 << LDOC)
#define LDOC_3V6                  (4 << LDOC)
#define LDOC_3V3                  (3 << LDOC)
#define LDOC_2V9                  (2 << LDOC)
#define LDOC_2V6                  (1 << LDOC)
#define LDOC_2V4                  (0 << LDOC)

#define LDOM                       2
#define LDOM_MSK                  (3 << LDOM)
#define LDOM_BLOUT                (3 << LDOM)
#define LDOM_HIGH                 (2 << LDOM)
#define LDOM_VDD                  (1 << LDOM)
#define LDOM_DISABLE              (0 << LDOM)

#define ENLDO                      1                
#define ENLDO_MSK                 (1 << ENLDO)
#define ENLDO_ENABLE              (1 << ENLDO)
#define ENLDO_DISABLE             (0 << ENLDO)

//AD1CN5//
#define LDOPL                      4                
#define LDOPL_MSK                 (1 << LDOPL)
#define LDOPL_ENABLE              (1 << LDOPL)
#define LDOPL_DISABLE             (0 << LDOPL)





/**************************************************************************************************|
|*                                      Function Level                                            *|
|**************************************************************************************************/

/*-------------------------------------------------------------------------------------------------|
|  Function-like Macro:                                                                            |
|    Register Bits field Configuration without function call overhead,                             |
|    user should take care of detail of h/w behavior and constrains.                               |
|-------------------------------------------------------------------------------------------------*/
#define PWR_BGREnable()                 (PWRCN |= ENBGR_ENABLE)
#define PWR_BGRDisable()                (PWRCN &= (~ENBGR_MSK))
#define PWR_LDOEnable()                 (PWRCN |= ENLDO_ENABLE)
#define PWR_LDODisable()                (PWRCN &= (~ENLDO_MSK))
#define PWR_LDOPLEnable()               (AD1CN5 |= LDOPL_ENABLE)
#define PWR_LDOPLDisable()              (AD1CN5 &= (~LDOPL_MSK))
//#define ADC_LDOPLEnable()               (AD1CN5 |= LDOPL_ENABLE)
//#define ADC_LDOPLDisable()              (AD1CN5 &= (~LDOPL_MSK))
#define PWR_ENACMEnable()               (AD1CN5 |= ENACM_ENABLE)
#define PWR_ENACMDisable()              (AD1CN5 &=(~ENACM_MSK))
//#define ADC_ENACMEnable()               (AD1CN5 |= ENACM_ENABLE)
//#define ADC_ENACMDisable()              (AD1CN5 &=(~ENACM_MSK))
#define PWR_VCMSSelect(vcms)           (AD1CN5 = ((AD1CN5 & (~VCMS_MSK)) | vcms))
//#define ADC_VCMSSelect(vcms)           (AD1CN5 = ((AD1CN5 & (~VCMS_MSK)) | vcms))
  
#define PWR_VDDASel(Sel)             (PWRCN = ((PWRCN & (~LDOC_MSK)) | Sel))
#define PWR_LDOMode(Sel)            (PWRCN = ((PWRCN & (~LDOM_MSK)) | Sel))


/*-------------------------------------------------------------------------------------------------|
|  Function call:                                                                                  |
|    For general and functional register access.                                                   |
|-------------------------------------------------------------------------------------------------*/
void PWR_VDDAOpen(unsigned char vdda);    //VDDA regulated selector

