/**************************************************************************************************|
|* Copyright 2021 Hycon Technology, Corp.                                                         *|
|* http://www.hycontek.com/                                                                       *|
|* Description:                                                                                   *|
|*                                                                                                *|
|**************************************************************************************************/

/**************************************************************************************************|
|*  Includes                                                                                      *|
|**************************************************************************************************/
#include <hy17m26sfr.h>
#include <SPI.h>
#include <INT.h>
/**************************************************************************************************|
|*  Static Function                                                                               *|
|**************************************************************************************************/

/**************************************************************************************************|
|*  Generic Peripheral Library                                                                    *|
|**************************************************************************************************/

/*----------------------------------------------------------------------------------------------------------------------------------------------------|
|  Function: SPI_Open                                                                      			     				   											|
|                                                                                                 																					|
|  Parameters:                                                                                                                                                         		     |	
|         uMode      - [in]	0~0xff			data baud rate = I2C_CLK / [4*(dbr+1)]																	 |
|         uCKP       - [in] CKP_HI: Idle status when High level                                                                                   		                 |
|                           CKP_LO: Idle status when Low level                                                              		                   		                   		                          |
|         uCKP       - [in] CKE_IDLE     : Transmit when clock changes from effective status to idle status                                                           		                   		                   		                           |             
|                           CKE_EFFECTIVE: Transmit when clock changes from idle status to effective status                                                           		                   		                   		                                        
|                                                                                       		                   		                   		                                        
|  Returns:                                                                               		                                                                                  |
|         None               		                   		                   		                   		                   		                   		                       |
|                                                                                       		                   		                   		                                        
|  Description:                                                                                																					 
|         This function is used to open I2C               														   
|-------------------------------------------------------------------------------------------------------------------------------------------------------*/
void SPI_Open(unsigned char uMode,       // Configure SPI Mode
              unsigned char uCKP,        // Configure SPI Polarity  
              unsigned char uCKE)       // Configure SPI Transmit Timing
{
  SSPCN0=0;
  SPI0_ModeSelect(uMode);  
  SPI0_PolarityConfig(uCKP);   
  SPI0_SendConfig(uCKE);      

  SPIIE_Enable();
  SPIIF_ClearFlag();
  SPI0_Enable(); 

}
