/**************************************************************************************************|
|* Copyright 2021 Hycon Technology, Corp.                                                         *|
|* http://www.hycontek.com/                                                                       *|
|* Description:                                                                                   *|
|*                                                                                                *|
|**************************************************************************************************/

/**************************************************************************************************|
|*  Includes                                                                                      *|
|**************************************************************************************************/
#include <hy17m26sfr.h>
#include <TMR.h>
#include <CLK.h>
#include <INT.h>


/**************************************************************************************************|
|*  Static Function                                                                               *|
|**************************************************************************************************/

/**************************************************************************************************|
|*  Generic Peripheral Library                                                                    *|
|**************************************************************************************************/
/*-------------------------------------------------------------------------------------------------|
|  Function: TMA1_Open                                                                             |
|                                                                                                  |
|  Parameters:                                                                                     |
|         ck        - [in] TMAS_DMSCK / TMAS_LPCCK                                                 |
|         cks       - [in] DTMA_TMACKDIV2    / DTMA_TMACKDIV4                                      |
|                          DTMA_TMACKDIV8    / DTMA_TMACKDIV16                                     |
|                          DTMA_TMACKDIV32   / DTMA_TMACKDIV64                                     |
|                          DTMA_TMACKDIV128  / DTMA_TMACKDIV256                                    |
|          ck        - [in] 0x0~0xFF                                                               |
|  Returns:                                                                                        |
|         None                                                                                     |
|                                                                                                  |
|  Description:                                                                                    |
|         This function is used to open the Timer-A1(TMA1)                                           |
|-------------------------------------------------------------------------------------------------*/
void TMA1_Open(unsigned char ck,      //Timer-A operating frequency selector
              unsigned char cks,      //Timer-A overflow controller
              unsigned char tma_cmp)	//setting TMA comparison count
{
	TMA1_CLKSelect(ck);
	TMA1_CLKDiv(cks);
	TMA1_ClearTMA1R();
	TMA1_CompSet(tma_cmp);
	TMA1Enable();
	TA1IE_Enable();
}

/*-------------------------------------------------------------------------------------------------|
|  Function: TMA2_Open                                                                             |
|                                                                                                  |
|  Parameters:                                                                                     |
|         ck        - [in] TMAS_DMSCK / TMAS_LPCCK                                                 |
|         cks       - [in] DTMA_TMACKDIV2    / DTMA_TMACKDIV4                                      |
|                          DTMA_TMACKDIV8    / DTMA_TMACKDIV16                                     |
|                          DTMA_TMACKDIV32   / DTMA_TMACKDIV64                                     |
|                          DTMA_TMACKDIV128  / DTMA_TMACKDIV256                                    |
|          ck        - [in] 0x0~0xFF                                                               |
|  Returns:                                                                                        |
|         None                                                                                     |
|                                                                                                  |
|  Description:                                                                                    |
|         This function is used to open the Timer-A2(TMA2)                                           |
|-------------------------------------------------------------------------------------------------*/
void TMA2_Open(unsigned char ck,      //Timer-A operating frequency selector
              unsigned char cks,      //Timer-A overflow controller
              unsigned char tma_cmp)	//setting TMA comparison count
{
	TMA2_CLKSelect(ck);
	TMA2_CLKDiv(cks);
	TMA2_ClearTMA2R();
	TMA2_CompSet(tma_cmp);
	TMA2Enable();
	TA2IE_Enable();
}

/*-------------------------------------------------------------------------------------------------|
|  Function: TMB1_Open                                                                             |
|                                                                                                  |
|  Parameters:                                                                                     |
|         ck        - [in] TMBS_LPCCK / TMBS_HSCK                                                  |
|         cks       - [in] DTMB_TMBCKDIV8    / DTMB_TMBCKDIV4                                      |
|                          DTMB_TMBCKDIV2   / DTMB_TMBCKDIV1                                       |
|         mode       - [in] TB1M_16bit / TB1M_17bit / TB1M_2_8bit / TB1M_8_8bit                    |
|         trig_mode        - [in] TB1RT_LogicH / TB1RT_CP11                                        |
|  Returns:                                                                                        |
|         None                                                                                     |
|                                                                                                  |
|  Description:                                                                                    |
|         This function is used to open the Timer-B1(TMB1)                                         |
|-------------------------------------------------------------------------------------------------*/
void TMB1_Open(unsigned char ck,
						  unsigned char cks,
						  unsigned char mode,
						  unsigned char trig_mode)
{
	CLK_TMBCKDivSelect(cks);
	CLK_TMBCKSelect(ck);
	TB1_ModeSelect(mode);
	TB1_TRIG_MODE(trig_mode);
	TB1IE_Enable();
}

void TB1C0Set(unsigned int TMB)
{
	TB1C0H=(TMB>>8);
	TB1C0L= (0x00FF & TMB);
}

void TB1C1Set(unsigned int TMB)
{
	TB1C1H=(TMB>>8);
	TB1C1L= (0x00FF & TMB);
}

void TB1C2Set(unsigned int TMB)
{
	TB1C2H=(TMB>>8);
	TB1C2L= (0x00FF & TMB);
}


/*-------------------------------------------------------------------------------------------------|
|  Function: TMB2_Open                                                                             |
|                                                                                                  |
|  Parameters:                                                                                     |
|         ck         - [in] TMB2S_LPCCK / TMBS_HSCK                                                |
|         cks        - [in] DTMB2_TMBCKDIV8   / DTMB2_TMBCKDIV4                                    |
|                          DTMB2_TMBCKDIV2   / DTMB2_TMBCKDIV1                                     |
|         mode       - [in] TB2M_16bit / TB2M_17bit / TB2M_2_8bit / TB2M_8_8bit                    |
|         trig_mode  - [in] TB2RT_LogicH / TB2RT_CP11                                              |
|  Returns:                                                                                        |
|         None                                                                                     |
|                                                                                                  |
|  Description:                                                                                    |
|         This function is used to open the Timer-B2(TMB2)                                         |
|-------------------------------------------------------------------------------------------------*/
void TMB2_Open(unsigned char ck,
						  unsigned char cks,
						  unsigned char mode,
						  unsigned char trig_mode)
{
	CLK_TMB2CKDivSelect(cks);
	CLK_TMB2CKSelect(ck);
	TB2_ModeSelect(mode);
	TB2_TRIG_MODE(trig_mode);
	TB2IE_Enable();
}

void TB2C0Set(unsigned int TMB)
{
	TB2C0H=(TMB>>8);
	TB2C0L= (0x00FF & TMB);
}

void TB2C1Set(unsigned int TMB)
{
	TB2C1H=(TMB>>8);
	TB2C1L= (0x00FF & TMB);
}

void TB2C2Set(unsigned int TMB)
{
	TB2C2H=(TMB>>8);
	TB2C2L= (0x00FF & TMB);
}