/**************************************************************************************************|
|* Copyright 2021 Hycon Technology, Corp.                                                         *|
|* http://www.hycontek.com/                                                                       *|
|* Description:                                                                                   *|
|*                                                                                                *|
|**************************************************************************************************/

/**************************************************************************************************|
|*  Includes                                                                                      *|
|**************************************************************************************************/
#include <hy17m26sfr.h>
#include <UART.h>
#include <GPIO.h>
#include <INT.h>

/**************************************************************************************************|
|*  Static Function                                                                               *|
|**************************************************************************************************/

/**************************************************************************************************|
|*  Generic Peripheral Library                                                                    *|
|**************************************************************************************************/

/*---------------------------------------------------------------------------------------------------------------------------------|
|  Function: UART0_Open                                                                                                                      |
|                                                                                                                                                             |
|  Parameters:                                                                                                                                       |
|         uBRGR     - [in] Desired baud rate.                                                                                             |
|         uDataBits - [in] "8"                 *8 bit mode*                                                                                   |
|                                  "9"                 *9 bit mode*                                                                                   |
|         uParity     - [in] PARITY_ODD / PARITY_Even / PARITY_None                                                 |
|                                                                                                                                                              |
|  Returns:                                                                                                                                               |
|         None                                                                                                                                             |
|                                                                                                                                                               |
|  Description:                                                                                                                                          |
|         This function is used to open                                                                                                        |
|                  the Enhanced Universal Asynchronous Receiver Transmitter(UART)                                |
|-------------------------------------------------------------------------------------------------------------------------------------*/
void UART0_Open(unsigned int uBG0R,     //desired baud rate
               unsigned char uDataBits, //Enable the transmission of the ninth bit and send the ninth bit data
               unsigned char uParity)     //Odd/even bit check
{

	BG0RH=(uBG0R>>8);
	BG0RL= (0x00FF & uBG0R);

    if (uDataBits==9)
    {
        UART0_TX9Enable();
        UART0_RC9Enable();
    }
    else
    {
        UART0_TX9Disable();
        UART0_RC9Disable();
    }
    UART0_Parity(uParity);
    UART0_TXEnable();
    UART0_CREnable(); 		    

    UART0_Enable();	
    
}
/*---------------------------------------------------------------------------------------------------------------------------------|
|  Function: UART0_BGRSet                                                                                                                      |
|                                                                                                                                                             |
|  Parameters:                                                                                                                                       |
|         uBG0R     - [in] UART send data                                                                                             |
|                                                                                                                                                               |
|  Returns:                                                                                                                                               |
|         None                                                                                                                                             |
|                                                                                                                                                               |
|  Description:                                                                                                                                          |
|         This function is used to set the UART send data                                                                          |
|                                                                                                                                                               |
|-------------------------------------------------------------------------------------------------------------------------------------*/
void UART0_BGRSet(unsigned int uBG0R)
{
	BG0RH=(uBG0R>>8);
	BG0RL= (0x00FF & uBG0R);
}

/*---------------------------------------------------------------------------------------------------------------------------------|
|  Function: UART2_Open                                                                                                                      |
|                                                                                                                                                             |
|  Parameters:                                                                                                                                       |
|         uBRGR     - [in] Desired baud rate.                                                                                             |
|         uDataBits - [in] "8"                 *8 bit mode*                                                                                   |
|                                  "9"                 *9 bit mode*                                                                                   |
|         uParity     - [in] PARITY_ODD / PARITY_Even / PARITY_None                                                 |
|                                                                                                                                                              |
|  Returns:                                                                                                                                               |
|         None                                                                                                                                             |
|                                                                                                                                                               |
|  Description:                                                                                                                                          |
|         This function is used to open                                                                                                        |
|                  the Enhanced Universal Asynchronous Receiver Transmitter(UART)                                |
|-------------------------------------------------------------------------------------------------------------------------------------*/
void UART2_Open(unsigned int uBG2R,     //desired baud rate
               unsigned char uDataBits, //Enable the transmission of the ninth bit and send the ninth bit data
               unsigned char uParity)     //Odd/even bit check
{

	BG2RH=(uBG2R>>8);
	BG2RL= (0x00FF & uBG2R);

    if (uDataBits==9)
    {
        UART2_TX9Enable();
        UART2_RC9Enable();
    }
    else
    {
        UART2_TX9Disable();
        UART2_RC9Disable();
    }
    UART2_Parity(uParity);
    UART2_TXEnable();
    UART2_CREnable();

    UART2_Enable();	
    
}
/*---------------------------------------------------------------------------------------------------------------------------------|
|  Function: UART2_BGRSet                                                                                                                      |
|                                                                                                                                                             |
|  Parameters:                                                                                                                                       |
|         uBG0R     - [in] UART send data                                                                                             |
|                                                                                                                                                               |
|  Returns:                                                                                                                                               |
|         None                                                                                                                                             |
|                                                                                                                                                               |
|  Description:                                                                                                                                          |
|         This function is used to set the UART send data                                                                          |
|                                                                                                                                                               |
|-------------------------------------------------------------------------------------------------------------------------------------*/
void UART2_BGRSet(unsigned int uBG2R)
{
	BG2RH=(uBG2R>>8);
	BG2RL= (0x00FF & uBG2R);
}