/**************************************************************************************************|
|* Copyright 2021 Hycon Technology, Corp.                                                         *|
|* http://www.hycontek.com/                                                                       *|
|* Description:                                                                                   *|
|* - Generic Peripheral Library: A general and functional Interface for the specific Peripheral   *|
|* - Low Level Peripheral Access: Register-Bits Level access Macro, user must take care           *|
|*   of calling procedure and hardware constraints                                                *|
|* - Support Target: HY17M Series                                                                 *|
|**************************************************************************************************/

/**************************************************************************************************|
|*                               Peripheral Register Bits field                                   *|
|**************************************************************************************************/
#include <INT.h>           // Interrupt Config for UART

// UR0CN // // UR2CN //
#define ENSP                             7
#define ENSP_MSK                        (1 << ENSP)
#define ENSP_ENABLE                     (1 << ENSP)
#define ENSP_DISABLE                    (0 << ENSP)

#define ENTX                             6
#define ENTX_MSK                        (1 << ENTX)
#define ENTX_ENABLE                     (1 << ENTX)
#define ENTX_DISABLE                    (0 << ENTX)
                                        
#define TX9                              5
#define TX9_MSK                         (1 << TX9)
#define TX9_ENABLE                      (1 << TX9)
#define TX9_DISABLE                     (0 << TX9)		

#define TX9D                             4
#define TX9D_MSK                        (1 << TX9D)
#define TX9D_1                          (1 << TX9D)
#define TX9D_0                          (0 << TX9D)

#define PARITY                           3
#define PARITY_MSK                      (1 << PARITY)
#define PARITY_ODD                      (1 << PARITY)
#define PARITY_EVEN                     (0 << PARITY)
#define PARITY_None                      (0 << PARITY)

#define WUE                              0
#define WUE_MSK                         (1 << WUE)
#define WUE_ENABLE                      (1 << WUE)
#define WUE_DISABLE                     (0 << WUE)								

// UR0STA // // UR2STA //
#define RC9D                             6
#define RC9D_MSK                        (1 << RC9D)
#define RC9D_1                          (1 << RC9D)
#define RC9D_0                          (0 << RC9D)

#define PERR                             5
#define PERR_MSK                        (1 << PERR)
#define PERR_ERR                        (1 << PERR)
#define PERR_PASS                       (0 << PERR)

#define FERR                             4
#define FERR_MSK                        (1 << FERR)
#define FERR_FAIL                       (1 << FERR)
#define FERR_PASS                       (0 << FERR)

#define OERR                             3
#define OERR_MSK                        (1 << OERR)
#define OERR_1                          (1 << OERR)
#define OERR_0                          (0 << OERR)

#define RCIDL                            2
#define RCIDL_MSK                       (1 << RCIDL)
#define RCIDL_1                         (1 << RCIDL)
#define RCIDL_0                         (0 << RCIDL)

#define TRMT                             1
#define TRMT_MSK                        (1 << TRMT)
#define TRMT_1                          (1 << TRMT)
#define TRMT_0                          (0 << TRMT)

#define ABDOVF                           0
#define ABDOVF_MSK                      (1 << ABDOVF)
#define ABDOVF_1                        (1 << ABDOVF)
#define ABDOVF_0                        (0 << ABDOVF)

// BA0CN // // BA2CN //
#define UARTSE                           7
#define UARTSE_MSK                      (1 << UARTSE)
#define UARTSE_CPUCK                    (1 << UARTSE)
#define UARTSE_LPCCK                    (0 << UARTSE)

#define ENCR                             3
#define ENCR_MSK                        (1 << ENCR)
#define ENCR_ENABLE                     (1 << ENCR)
#define ENCR_DISABLE                    (0 << ENCR)

#define RC9                              2
#define RC9_MSK                         (1 << RC9)
#define RC9_ENABLE                      (1 << RC9)
#define RC9_DISABLE                     (0 << RC9)

#define ENADD                            1
#define ENADD_MSK                       (1 << ENADD)
#define ENADD_ENABLE                    (1 << ENADD)
#define ENADD_DISABLE                   (0 << ENADD)

#define ENABD                            0
#define ENABD_MSK                       (1 << ENABD)
#define ENABD_ENABLE                    (1 << ENABD)
#define ENABD_DISABLE                   (0 << ENABD)


/*-------------------------------------------------------------------------------------------------|
|  Function-like Macro:                                                                            |
|    Register Bits field Configuration without function call overhead,                             |
|    user should take care of detail of h/w behavior and constrains.                               |
|-------------------------------------------------------------------------------------------------*/
//CLK Config function for Peripherals were placed in each peripheral module individually
//CLK Config for MCU(System Clock)were declared/defined below

#define UART0_Enable()            (UR0CN |= ENSP_ENABLE)
#define UART0_Disable()           (UR0CN &= ~(ENSP_MSK))
#define UART0_TXEnable()         (UR0CN |= ENTX_ENABLE)
#define UART0_TXDisable()        (UR0CN &= ~(ENTX_MSK))
#define UART0_TX9Enable()        (UR0CN |= TX9_ENABLE)
#define UART0_TX9Disable()       (UR0CN &= ~(TX9_MSK))
#define UART0_TX9Data(Sel)       (UR0CN =  (UR0CN & (~TX9D_MSK)) | (Sel))
#define UART0_Parity(Sel)        (UR0CN =  (UR0CN & (~PARITY_MSK)) | (Sel))
#define UART0_WUEEnable()        (UR0CN |= WUE_ENABLE)
#define UART0_WUEDisable()       (UR0CN &= ~(WUE_MSK))

#define UART0_GetRC9D()          (UR0STA & RC9D_MSK)
#define UART0_GetPERR()          (UR0STA & PERR_MSK)
#define UART0_GetFERR()          (UR0STA & FERR_MSK)
#define UART0_GetOERR()          (UR0STA & OERR_MSK)
#define UART0_GetRCIDL()         (UR0STA & RCIDL_MSK)
#define UART0_GetTRMT()          (UR0STA & TRMT_MSK)
#define UART0_GetABDOVF()        (UR0STA & ABDOVF_MSK)

#define UART0_CLKSelect(clk)     (BA0CN = ((BA0CN & (~UARTSE_MSK)) | clk))
#define UART0_CREnable()         (BA0CN = BA0CN |ENCR_ENABLE)
#define UART0_CRDisable()        (BA0CN &= ~(ENCR_MSK))
#define UART0_RC9Enable()        (BA0CN = BA0CN |RC9_ENABLE)
#define UART0_RC9Disable()       (BA0CN &= ~(RC9_MSK))
#define UART0_ADDEnable()        (BA0CN = BA0CN |ENADD_ENABLE)
#define UART0_ADDDisable()       (BA0CN &= ~(ENADD_MSK))
#define UART0_ABDEnable()        (BA0CN = BA0CN |ENABD_ENABLE)
#define UART0_ABDDisable()       (BA0CN &= ~(ENABD_MSK))


#define UART0_INT_TXEnable()        (INTE1 |= TXIE_ENABLE)
#define UART0_INT_TXDisable()          (INTE1 &= (~TXIE_MSK))
#define UART0_INT_RCEnable()        (INTE1 |= RCIE_ENABLE)
#define UART0_INT_RCDisable()          (INTE1 &= (~RCIE_MSK))

#define UART0_INT_RCIsFlag()             (INTF1 & RCIF_SET)
#define UART0_INT_TXIsFlag()              (INTF1 & TXIF_SET)
#define UART0_INT_RCClearFlag()        (INTF1 &= (~RCIF_MSK))
#define UART0_INT_TXClearFlag()         (INTF1 &= (~TXIF_MSK))

//#define TXIE_Enable()               (INTE1 |= TXIE_ENABLE)
//#define TXIE_Disable()              (INTE1 &= (~TXIE_MSK))
//#define TXIF_IsFlag()               (INTF1 & TXIF_SET)
//#define TXIF_ClearFlag()            (INTF1 &= (~TXIF_MSK))

//#define RCIE_Enable()               (INTE1 |= RCIE_ENABLE)
//#define RCIE_Disable()              (INTE1 &= (~RCIE_MSK))
//#define RCIF_IsFlag()               (INTF1 & RCIF_SET)
//#define RCIF_ClearFlag()            (INTF1 &= (~RCIF_MSK))


#define UART2_Enable()            (UR2CN |= ENSP_ENABLE)
#define UART2_Disable()           (UR2CN &= ~(ENSP_MSK))
#define UART2_TXEnable()         (UR2CN |= ENTX_ENABLE)
#define UART2_TXDisable()        (UR2CN &= ~(ENTX_MSK))
#define UART2_TX9Enable()        (UR2CN |= TX9_ENABLE)
#define UART2_TX9Disable()       (UR2CN &= ~(TX9_MSK))
#define UART2_TX9Data(Sel)       (UR2CN =  (UR2CN & (~TX9D_MSK)) | (Sel))
#define UART2_Parity(Sel)        (UR2CN =  (UR2CN & (~PARITY_MSK)) | (Sel))
#define UART2_WUEEnable()        (UR2CN |= WUE_ENABLE)
#define UART2_WUEDisable()       (UR2CN &= ~(WUE_MSK))

#define UART2_GetRC9D()          (UR2STA & RC9D_MSK)
#define UART2_GetPERR()          (UR2STA & PERR_MSK)
#define UART2_GetFERR()          (UR2STA & FERR_MSK)
#define UART2_GetOERR()          (UR2STA & OERR_MSK)
#define UART2_GetRCIDL()         (UR2STA & RCIDL_MSK)
#define UART2_GetTRMT()          (UR2STA & TRMT_MSK)
#define UART2_GetABDOVF()        (UR2STA & ABDOVF_MSK)

#define UART2_CLKSelect(clk)     (BA2CN = ((BA2CN & (~UARTSE_MSK)) | clk))
#define UART2_CREnable()         (BA2CN = BA2CN |ENCR_ENABLE)
#define UART2_CRDisable()        (BA2CN &= ~(ENCR_MSK))
#define UART2_RC9Enable()        (BA2CN = BA2CN |RC9_ENABLE)
#define UART2_RC9Disable()       (BA2CN &= ~(RC9_MSK))
#define UART2_ADDEnable()        (BA2CN = BA2CN |ENADD_ENABLE)
#define UART2_ADDDisable()       (BA2CN &= ~(ENADD_MSK))
#define UART2_ABDEnable()        (BA2CN = BA2CN |ENABD_ENABLE)
#define UART2_ABDDisable()       (BA2CN &= ~(ENABD_MSK))


#define UART2_INT_TXEnable()        (INTE3 |= TX2IE_ENABLE)
#define UART2_INT_TXDisable()          (INTE3 &= (~TX2IE_MSK))
#define UART2_INT_RCEnable()        (INTE3 |= RC2IE_ENABLE)
#define UART2_INT_RCDisable()          (INTE3 &= (~RC2IE_MSK))

#define UART2_INT_RCIsFlag()             (INTF3 & RC2IF_SET)
#define UART2_INT_TXIsFlag()              (INTF3 & TX2IF_SET)
#define UART2_INT_RCClearFlag()        (INTF3 &= (~RC2IF_MSK))
#define UART2_INT_TXClearFlag()         (INTF3 &= (~TX2IF_MSK))

//#define TX2IE_Enable()               (INTE3 |= TX2IE_ENABLE)
//#define TX2IE_Disable()              (INTE3 &= (~TX2IE_MSK))
//#define TX2IF_IsFlag()               (INTF3 & TX2IF_SET)
//#define TX2IF_ClearFlag()            (INTF3 &= (~TX2IF_MSK))

//#define RC2IE_Enable()               (INTE3 |= RC2IE_ENABLE)
//#define RC2IE_Disable()              (INTE3 &= (~RC2IE_MSK))
//#define RC2IF_IsFlag()               (INTF3 & RC2IF_SET)
//#define RC2IF_ClearFlag()            (INTF3 &= (~RC2IF_MSK))

void UART0_Open(unsigned int uBG0R,     // desired baud rate
               unsigned char uDataBits,       // Enable the transmission of the ninth bit and send the ninth bit data
               unsigned char uParity);              // Odd/even bit check
void UART0_BGRSet(unsigned int uBG0R);

void UART2_Open(unsigned int uBG2R,     // desired baud rate
               unsigned char uDataBits,       // Enable the transmission of the ninth bit and send the ninth bit data
               unsigned char uParity);              // Odd/even bit check
void UART2_BGRSet(unsigned int uBG2R);

